pub fn open_mint_viewing_memo(
    keys: &HashMap<ViewerPubKey, ViewerKeyPair>,
    mint: &MintNote
) -> Result<ViewingMemoOpening, ViewingError>
Attempt to open the viewer memo attached to a CAP mint transaction.

keys should be the caller’s collection of viewing key pairs, indexed by public key.