pub struct Block { /* private fields */ }Expand description
A block of CAP transactions.
A Block is a list of CAP transactions, plus the intended index of the block. The index ensures that all committed blocks are unique.
Implementations