pub struct Validator<const H: u8> {
pub block_height: u64,
pub records_commitment: MerkleCommitment,
pub records_frontier: MerkleFrontier,
}Expand description
A mock CAP validator.
The minimal validator will not actually validate. It only does the least it can do to implement the Validator interface, namely
- compute a unique commitment after each block (this is just the count of blocks)
- compute the UIDs and Merkle paths for the outputs of each block
Fields
block_height: u64records_commitment: MerkleCommitmentrecords_frontier: MerkleFrontierTrait Implementations
sourceimpl<'a, const H: u8> Arbitrary<'a> for Validator<H>
impl<'a, const H: u8> Arbitrary<'a> for Validator<H>
sourcefn arbitrary(u: &mut Unstructured<'a>) -> Result<Self>
fn arbitrary(u: &mut Unstructured<'a>) -> Result<Self>
Generate an arbitrary value of
Self from the given unstructured data. Read morefn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
fn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
Generate an arbitrary value of
Self from the entirety of the given
unstructured data. Read moresourceimpl<'de, const H: u8> Deserialize<'de> for Validator<H>
impl<'de, const H: u8> Deserialize<'de> for Validator<H>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<const H: u8> PartialEq<Validator<H>> for Validator<H>
impl<const H: u8> PartialEq<Validator<H>> for Validator<H>
sourceimpl<const H: u8> Validator for Validator<H>
impl<const H: u8> Validator for Validator<H>
type StateCommitment = u64
type StateCommitment = u64
A commitment to the state of the validator.
type Proof = ()
type Proof = ()
Additional data required to authenticate a committed block, not contained in the block
itself.
sourcefn block_height(&self) -> u64
fn block_height(&self) -> u64
The number of blocks this validator has applied.
sourcefn commit(&self) -> Self::StateCommitment
fn commit(&self) -> Self::StateCommitment
The commitment to the current state of the validator.
sourcefn next_block(&self) -> Self::Block
fn next_block(&self) -> Self::Block
Build a block on top of the current state of this validator. Read more
sourcefn validate_and_apply(
&mut self,
block: Self::Block,
_proof: Self::Proof
) -> Result<(Vec<u64>, MerkleTree), ValidationError>
fn validate_and_apply( &mut self, block: Self::Block, _proof: Self::Proof ) -> Result<(Vec<u64>, MerkleTree), ValidationError>
Apply a new block, updating the state and returning UIDs and Merkle paths for each output. Read more
impl<const H: u8> Eq for Validator<H>
impl<const H: u8> StructuralEq for Validator<H>
impl<const H: u8> StructuralPartialEq for Validator<H>