Struct reef::cap::LedgerWithHeight
source · pub struct LedgerWithHeight<const H: u8>;Expand description
A minimal CAP ledger.
The ledger implementation is parameterized on the height of Merkle trees that it will be used
with. Test code can use this to set the height very small (e.g. LedgerWithHeight<5>) to speed
up tests, while code that is trying to closely simulate a production environment can set a more
realistic height.